@@ -7,5 +7,5 @@ print(res)
 res=str(res)
 index=res.index("'")
 index1=res.index("'",index+1)
-res=res[index:index1]
+res=res[index+1:index1]
 print(res)
\ No newline at end of file
